#
# spec file for package kpmcore
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover 7
%bcond_without lang
Name:           kpmcore
Version:        3.3.0
Release:        bp153.2.2.1
Summary:        KDE Partition Manager core library
License:        GPL-3.0-only
Group:          Productivity/Office/Other
Url:            https://projects.kde.org/projects/extragear/sysadmin/kpmcore
Source:         http://download.kde.org/stable/%{name}/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kcoreaddons-devel
BuildRequires:  ki18n-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  libatasmart-devel
BuildRequires:  libblkid-devel
BuildRequires:  parted-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.7.0
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       libkpmcore%{sover} = %{version}

%description
Library for managing partitions. Common code for KDE Partition Manager and other projects.

%package devel
Summary:        Development package for KDE Partition Manager core library
Group:          Development/Languages/C and C++
Requires:       libkpmcore%{sover} = %{version}

%description devel
Library for managing partitions. Common code for KDE Partition Manager and other projects.

Development package for kpmcore.

%package -n libkpmcore%{sover}
Summary:        KDE Partition Manager core library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libkpmcore%{sover}
Library for managing partitions. Common code for KDE Partition Manager and other projects.

Main kpmcore library.

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang kpmcore
  %endif

%post -n libkpmcore%{sover} -p /sbin/ldconfig
%postun -n libkpmcore%{sover} -p /sbin/ldconfig

%files
%license COPYING.GPL3
%{_kf5_servicetypesdir}/*desktop
%{_kf5_plugindir}/*.so
%{_kf5_servicesdir}/*desktop

%files -n libkpmcore%{sover}
%license COPYING.GPL3
%{_libdir}/libkpmcore.so.*

%files devel
%{_libdir}/cmake/KPMcore/
%{_includedir}/kpmcore/
%{_libdir}/libkpmcore.so

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Oct 16 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%license
* Fri Dec 15 2017 wbauer@tmo.at
- Update to 3.3.0
  * some improvements for Btrfs, F2FS, NTFS file systems
  * first bits of new LUKS2 on-disk format support, now KDE
    Partition Manager can display LUKS2 labels. More LUKS2 work
    will follow in KPM 3.4.
  * There were changes in how LVM devices are detected which might
    be interesting if you use Calamares installer. In that case,
    you also need at least Calamares 3.1.8. Older versions will not
    compile against KPMcore 3.3.
  * KPMcore library now only depends on just three Tier 1
    Frameworks (I18n, CoreAddons, WidgetsAddons) instead of Tier 3
    (although, we will later require Tier 2 KAuth too)
- Drop fix-build-with-older-parted.patch, it cannot be built on
  Leap 42 anymore anyway because it needs newer Qt5 and blkid
* Sun Oct  1 2017 fabian@ritter-vogt.de
- Run spec-cleaner
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 3.2.0
  * Added support for UDF file system (this change requires
    util-linux 2.30). While adding support for UDF, the following
    general improvements were made:
    + KPM now supports setting label for file systems where it can
    only be done during initial formating (e.g. nilfs2 or udf)
    + File system label widget (QLineEdit) now validates its input
    for certain file systems (at the moment only FAT and UDF),
    not just maximum label length.
  * Detection support for ISO9660 file system
  * kpmcore now has lighter KDE Frameworks dependencies, KIO is no
    longer necessary, KIconThemes dependency moved from kpmcore to
    Partition Manager
  * kpmcore now has its own fstab parser and writer. Before we
    used to rely on glibc but it had no support for reading fstab
    comments, etc.
- Update build requirements
* Wed Jul  5 2017 wbauer@tmo.at
- Update to 3.1.2
  * Fix a possible null pointer dereference when glibc's getlogin
    function failed to return username of current user
* Mon Jun 19 2017 wbauer@tmo.at
- Update to 3.1.1
  * Disables plasma removable device automounting before doing any
    tasks.
* Fri Jun  2 2017 wbauer@tmo.at
- Update to 3.1.0
  * Fix some crashes when attempting to run without admin
    privileges
  * Improve support for changing file system labels online
  * Fix creation of LUKS volumes on some systems with NVMe disks
  * Require Qt 5.7
  * Detect Virtio KVM devices
- Remove INSTALL file from the package to fix an rpmlint warning
* Sun Feb  5 2017 wbauer@tmo.at
- Update to 3.0.3
  * some fixes for LUKS encrypted LVM logical volumes
* Fri Jan  6 2017 wbauer@tmo.at
- Update to 3.0.2
  * some "used space" fixes that are essential for Calamares
* Wed Jan  4 2017 fabian@ritter-vogt.de
- Run spec-cleaner
* Mon Jan  2 2017 wbauer@tmo.at
- Update to 3.0.1
  * fixes a bug in partition resizing widget that might lead to a
    data loss
* Mon Dec 19 2016 fabian@ritter-vogt.de
- Update to 3.0.0
- Update fix-build-with-older-parted.patch
* Fri Aug 26 2016 wbauer@tmo.at
- Update to 2.2.1
- Adjust build requirements
- Add fix-build-with-older-parted.patch to fix build on 13.2 and
  Leap 42
- Remove fix-build.diff, it's not needed anymore
* Sun Jun 19 2016 jacobwinski@gmail.com
- Update to 2.2.0.
- Update shared library name in spec file to reflect SONAME.
- Update spec description to fix desc shorter than summary error.
- Update patch so that it applies to new version.
* Sun Apr  3 2016 hrvoje.senjan@gmail.com
- Update to 2.1.1
* Mon Jan 18 2016 tittiatcoke@gmail.com
- Initial version 2.0.0
